@@ -93,7 +93,8 @@ class Zone():
     
     def write_bit_value(self, address, bit, value):
         new_value = change_bit_value(self._zone_state, address, bit, value)
-        self.write_register(0, new_value)
+        self._zone_state[address] = new_value
+        self.write_register(address, new_value)
 
     def __str__(self):
         return "Zone with id: " + str(self.zoneId) + \
@@ -129,6 +130,21 @@ class Zone():
         return ZoneMode(temp)
 
     def set_zone_mode(self, zoneMode):
+        zm = ZoneMode[zoneMode]
+        if zm == ZoneMode.MANUAL:
+            self.turnoff_automatic_mode()
+            self.turnoff_sleep()
+        elif zm == ZoneMode.MANUAL_SLEEP:
+            self.turnoff_automatic_mode()
+            self.turnon_sleep()
+        elif zm == ZoneMode.AUTOMATIC:
+            self.turnon_automatic_mode()
+            self.turnoff_sleep()
+        elif zm == ZoneMode.AUTOMATIC_SLEEP:
+            self.turnon_automatic_mode()
+            self.turnon_sleep()
+
+
         temp = change_range_bit_value(self._zone_state, 0, 0, 2, ZoneMode[zoneMode].value)
         self.write_register(0, temp)
 
